@@ -64,21 +64,24 @@ Render to
    &lt;
     
 =cut
+my %line_break = (NEL=>1);
 
 sub to_xhtml {
     my ( $self, $parser, $line ) = @_;
-
     #split by ;
     [
         map {
             s/^\s+//;
             s/\s+$//;
+            if ( exists $line_break{$_} ) {
+                $parser->mk_element('br');
+            } else {
             $parser->mk_characters( _to_xhtml_entity($_) )
+            }
           }
           split( /\s*;\s*/, $line )
     ];
 }
-
 sub _to_xhtml_entity {
     my $str = shift;
     if ( $str !~ /^\d/ ) {
@@ -87,7 +90,19 @@ sub _to_xhtml_entity {
         return sprintf( '&#%d;', $ord ) if defined $ord;
         return qq{&$str;};
     }
-    die "Number not supported in E<>";
+    # Otherwise, it's the numeric codepoint in some base...
+    else {
+        # Convert Perl 6 octals and decimals to Perl 5 notation...
+        if ($str !~ s{\A 0o}{0}xms) {       # Convert octal
+            $str =~ s{\A 0d}{}xms;          # Convert explicit decimal
+            $str =~ s{\A 0+ (?=\d)}{}xms;   # Convert implicit decimal
+        }
+
+        # Then return the XHTML numeric code...
+        return sprintf '&#%d;', eval $str;
+    }
+
+    die "Unsupported identity $_ in E<>";
 }
 
 =head2 to_docbook
@@ -101,8 +116,18 @@ Render to
 =cut
 
 sub to_docbook {
-    my ( $self, $parser, @in ) = @_;
-    return $self->to_xhtml( $parser, @in );
+    my ( $self, $parser, $line ) = @_;
+    #split by ;
+    [
+        map {
+            s/^\s+//;
+            s/\s+$//;
+            if (exists $line_break{$_} ) {()} else {
+            # <br/> not exists in docbook
+            $parser->mk_characters( _to_xhtml_entity($_) )}
+            }
+          split( /\s*;\s*/, $line )
+    ];
 }
 
 1;
