@@ -30,6 +30,7 @@ use warnings;
 use strict;
 use Data::Dumper;
 use Perl6::Pod::FormattingCode;
+use Perl6::Pod::Parser::Utils qw(parse_URI );
 use base 'Perl6::Pod::FormattingCode';
 
 sub on_para {
@@ -37,22 +38,22 @@ sub on_para {
 
     #extract linkname and content
     my ( $lname, $lcontent ) = ( '', defined $txt ? $txt : '' );
+    my $attr = $self->attrs_by_name;
+#=pod
     if ( $lcontent =~ /\|/ ) {
         my @all;
         ( $lname, @all ) = split( /\s*\|\s*/, $lcontent );
         $lcontent = join "", @all;
     }
-    my $attr = $self->attrs_by_name;
-
     #clean whitespaces
     $lname =~ s/^\s+//;
     $lname =~ s/\s+$//;
     $attr->{name} = $lname;
     my ( $scheme, $address, $section ) =
       $lcontent =~ /\s*(\w+)\s*\:([^\#]*)(?:\#(.*))?/;
-    $attr->{scheme} = $scheme;
+    $attr->{scheme} = $scheme||'';
     $address = '' unless defined $address;
-    $attr->{is_external} = $address =~ s/^\/\///;
+    $attr->{is_external} = $address =~ s/^\/\/// || $scheme && $scheme !~ /^file/;
 
     #clean whitespaces
     $address =~ s/^\s+//;
@@ -61,24 +62,35 @@ sub on_para {
 
     #fix L<doc:#Special Features>
     $attr->{section} = defined $section ? $section : '';
-    $txt;
+    #fix L<#id>
+    if (!defined($scheme) and $lcontent ) {
+        if ($lcontent =~ /^\s*(?:\#(.*))/) {
+            $attr->{section} = $1
+        }
+    }
+# =cut
+#    %{$attr} = %{parse_URI($txt)};
+    #parse nested formattings, i.e. L<B<name>|http://example.com>
+    $self->SUPER::on_para($parser,$lname)
 }
 
 sub to_xhtml {
     my ( $self, $parser, @in ) = @_;
     my $attr = $self->attrs_by_name();
     for ( $attr->{scheme} ) {
-        /^https?/ && do {
+        ( /^https?|.*$/ || $attr->{section} ) && do {
             my $a   = $parser->mk_element('a');
             my $url = $attr->{address};
             $url .= "#" . $attr->{section} if $attr->{section};
-            $url = $_ . "://" . $url if $attr->{is_external};
-            my $name = $attr->{name} || $attr->{address};
+            $url = $_ . ":". (/^https?/ ? '//' : '') . $url if $attr->{is_external};
+            my $name = $attr->{name} || $url;
             $a->attrs_by_name()->{href} = $url;
-            $a->add_content( $parser->mk_characters($name) );
+             $a->add_content( $parser->_make_events( scalar(@in) ? @in : $name ) );
             return $a;
           }
-          || do { return $parser->mk_characters( $in[0] ) }
+          || do { 
+            return [ $parser->_make_events(@in) ];
+            }
     }
 }
 
@@ -86,7 +98,7 @@ sub to_docbook {
     my ( $self, $parser, @in ) = @_;
     my $attr = $self->attrs_by_name();
     for ( $attr->{scheme} ) {
-        /^https?/ && do {
+        /^https?/  && do {
             my $ulink = $parser->mk_element('ulink');
             my $url   = $attr->{address};
             $url .= "#" . $attr->{section} if $attr->{section};
@@ -105,13 +117,13 @@ sub to_docbook {
 
 }
 1;
-
 __END__
 
-
 =head1 SEE ALSO
 
-L<http://perlcabal.org/syn/S26.html>
+L<http://zag.ru/perl6-pod/S26.html>,
+Perldoc Pod to HTML converter: L<http://zag.ru/perl6-pod/>,
+Perl6::Pod::Lib
 
 =head1 AUTHOR
 
@@ -119,12 +131,11 @@ Zahatski Aliaksandr, <zag@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009 by Zahatski Aliaksandr
+Copyright (C) 2009-2010 by Zahatski Aliaksandr
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.8.8 or,
 at your option, any later version of Perl 5 you may have available.
 
-
 =cut
 
